@@ -169,7 +169,7 @@ class ImageSetField(fields.Field):
 
     - version name
     - version label
-    - crop aspect ratio for the version
+    - crop aspect ratio for the version (optional)
 
     """
 
@@ -178,15 +178,29 @@ class ImageSetField(fields.Field):
     def __init__(self,
         label=None,
         versions=None,
+        fix_crop_aspect_ratio=False,
         validators=None,
         render_kw=None,
         **kwargs
     ):
 
-        assert versions, 'You must give at least one version for an image set'
+        assert versions, 'You must give at least one version for an image set.'
+
+        version_length = len(versions[0])
+        assert version_length in [2, 3], (
+            '`versions` argument must me given as '
+            '(name, label) or (name, label, crop_ratio).'
+        )
         for version in versions:
-            assert len(version) == 3, \
-                    'Versions must contain 3 values (name, label, crop ratio)'
+            assert len(version) == version_length, (
+                'Each item in the `versions` argument must be the same '
+                'length.'
+            )
+
+        assert not fix_crop_aspect_ratio or version_length == 3, (
+            '`fix_crop_aspect_ratio` can not be true unless crop ratios have '
+            'been given for each version.'
+        )
 
         if not render_kw:
             render_kw = {}
@@ -205,9 +219,13 @@ class ImageSetField(fields.Field):
         ])
 
         # Set the crop ratio for each version in the image set
-        render_kw['data-mh-image-set--crop-aspect-ratios'] = ','.join([
-            str(v[2]) for v in versions
-        ])
+        if version_length == 3:
+            render_kw['data-mh-image-set--crop-aspect-ratios'] = ','.join([
+                str(v[2]) for v in versions
+            ])
+
+        if fix_crop_aspect_ratio:
+            render_kw['data-mh-image-set--fix-crop-aspect-ratio'] = True
 
         # Default to accepting only images
         if 'data-mh-image-set--accept' not in render_kw:
