@@ -1,5 +1,6 @@
 from flask import current_app
 from .assets import Asset
+from .image_sets import ImageSet
 
 __all__ = [
     'min_file_projection',
@@ -62,7 +63,11 @@ def min_image_set_projection(field, versions, extra=None):
 
     for version in versions:
         projection.update(
-            min_image_projection('.'.join([field, 'images', version]), extras)
+            min_image_projection(
+                '.'.join([field, 'images', version]),
+                version,
+                extra
+            )
         )
 
     return projection
